pub enum Error {
Migrations(Error),
Pool(PoolError),
Postgres(Error),
Serde(Error),
InvalidPageToken(Box<dyn Error + Send + Sync>),
}Expand description
Errors that can occur when using the Postgres backend.
Variants
Migrations(Error)
An error occurred during database migrations.
Pool(PoolError)
An error occurred while acquiring a database connection from the pool.
Postgres(Error)
An error occurred during a database operation.
Serde(Error)
An error occurred while serializing or deserializing JSON data.
InvalidPageToken(Box<dyn Error + Send + Sync>)
An error occurred while converting a value to or from a database type.